package com.lyg.application.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lyg.application.entity.TaPost;
import com.lyg.application.service.TaPostService;
import com.lyg.common.util.StringUtil;
import com.lyg.framework.accesslimit.AccessLimit;
import com.lyg.framework.log.OpLog;
import com.lyg.system.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 文章;(ta_post)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2024-3-22
 */
@Api(tags = "文章对象功能接口")
@RestController
@RequestMapping("/")
public class TaPostController extends BaseController {

    @Autowired
    private TaPostService taPostService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "文章", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taPost/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {

        TaPost taPost = taPostService.getByPostId(id);

        return SaResult.data(taPost);
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "文章", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/taPost")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("标题") @RequestParam(value = "title", required = false) String title,
                         @ApiParam("作者") @RequestParam(value = "author", required = false) String author,
                         @ApiParam("正序排列") @RequestParam(value = "sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value = "sortDesc", defaultValue = "created_time") String sortDesc) throws Exception {

        IPage<TaPost> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaPost> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtil.isNotEmpty(title),"title", title);
        queryWrapper.like(StringUtil.isNotEmpty(author), "author", author);
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<TaPost> result = taPostService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param taPost 实例对象
     * @return 实例对象
     */
    @OpLog(module = "文章", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/taPost")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody TaPost taPost) throws Exception {

        if (taPost == null) {
            throw new Exception("数据不为空");
        }
        taPostService.savePost(taPost);
        return SaResult.data(taPost);
    }

    /**
     * 更新数据
     *
     * @param taPost 实例对象
     * @return 实例对象
     */
    @OpLog(module = "文章", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/taPost/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody TaPost taPost,
                         @ApiParam("对象ID") @PathVariable String id) throws Exception {
        taPost.setPostId(id);
        taPostService.updateById(taPost);
        return SaResult.data(taPost);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "文章", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taPost/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        taPostService.removeById(id);
        return SaResult.data("success");
    }
}